/*
 * ViSP, open source Visual Servoing Platform software.
 * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file LICENSE.txt at the root directory of this source
 * distribution for additional information about the GNU GPL.
 *
 * For using ViSP with software that can not be combined with the GNU
 * GPL, please contact Inria about acquiring a ViSP Professional
 * Edition License.
 *
 * See https://visp.inria.fr for more information.
 *
 * This software was developed at:
 * Inria Rennes - Bretagne Atlantique
 * Campus Universitaire de Beaulieu
 * 35042 Rennes Cedex
 * France
 *
 * If you have questions regarding the use of this file, please contact
 * Inria at visp@inria.fr
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Description:
 * Error that can be emitted by the vpPose class and its derivatives
 */

#ifndef _vpPoseException_h_
#define _vpPoseException_h_

#include <visp3/core/vpException.h>

#include <iostream>
#include <string>   

/*!
 * \class vpPoseException
 * \ingroup group_vision_pose
 * \brief Error that can be emitted by the vpPose class and its derivatives.
 */
class VISP_EXPORT vpPoseException : public vpException
{
public:
  /*!
   * Lists the possible error than can be emitted while calling
   * vpPose member
   */
  enum errorCodeEnum
  {
    //! Generic pose error
    poseError,
    //! Something is not initialized
    notInitializedError,
    //! Function not implemented
    notImplementedERR,
    //! Index out of range
    outOfRangeError,
    //! Not enough points to compute the pose
    notEnoughPointError
  };

public:
  /*!
   * Constructor.
   */
  vpPoseException(int id, const char *format, ...)
  {
    this->code = id;
    va_list args;
    va_start(args, format);
    setMessage(format, args);
    va_end(args);
  }

  /*!
   * Constructor.
   */
  vpPoseException(int id, const std::string &msg) : vpException(id, msg) { }

  /*!
   * Constructor.
   */
  explicit vpPoseException(int id) : vpException(id) { }
};

#endif
